@@ -13,14 +13,13 @@ class DCORThemePlugin(p.SingletonPlugin):
 
     # IBlueprint
     def get_blueprint(self):
-        u'''Return a Flask Blueprint object to be registered by the app.'''
+        """Return a Flask Blueprint object to be registered by the app."""
         # Create Blueprint for plugin
         blueprint = Blueprint(self.name, self.__module__)
 
         # Add plugin url rules to Blueprint object
         rules = [
             ('/contact', 'contact', lambda: render_template('contact.html')),
-            ('/help', 'help', lambda: render_template('help.html')),
             ('/imprint', 'imprint', lambda: render_template('imprint.html')),
             ('/privacy', 'privacy', lambda: render_template('privacy.html')),
         ]
